antares.apps.subscription.service package
=========================================

Module contents
---------------

.. automodule:: antares.apps.subscription.service
   :members:
   :undoc-members:
   :show-inheritance:
